@@ -20,7 +20,7 @@
 
 using namespace IncidenceEditorNG;
 
-SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTime, int duration, ConflictResolver *resolver, QWidget *parent)
+SchedulingDialog::SchedulingDialog(QDate startDate, QTime startTime, int duration, ConflictResolver *resolver, QWidget *parent)
     : QDialog(parent)
     , mResolver(resolver)
     , mPeriodModel(new CalendarSupport::FreePeriodModel(this))
@@ -78,9 +78,7 @@ SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTim
     mMoveApptGroupBox->hide();
 }
 
-SchedulingDialog::~SchedulingDialog()
-{
-}
+SchedulingDialog::~SchedulingDialog() = default;
 
 void SchedulingDialog::slotUpdateIncidenceStartEnd(const QDateTime &startDateTime, const QDateTime &endDateTime)
 {
@@ -203,3 +201,5 @@ QTime SchedulingDialog::selectedStartTime() const
 {
     return mSelectedTime;
 }
+
+#include "moc_schedulingdialog.cpp"
